@@ -1,5 +1,5 @@
 prune2data<-function(tree,species){
-if(class(tree) != "phylo") stop("Tree must be of class phylo")
+if(is(tree,"phylo")==FALSE) stop("Tree must be of class phylo")
 allnames<-c(species,tree$tip.label)
 droplist<-which(!tree$tip.label%in%species)
 drop<-tree$tip.label[droplist]
